@@ -8,12 +8,12 @@ class Arg:
     input: Final[str] = "_input"
     result: Final[str] = "_result"
 
-    def __init__(self, name: str, d_type: FnT):
+    def __init__(self, name: str, d_type: str):
         self.name = name
         self.type = d_type
 
     def to_str(self) -> str:
-        return f"{self.name}\t{self.type.value}"
+        return f"{self.name}\t{self.type}"
 
 
 class APlPgSqlFunction(metaclass=abc.ABCMeta):
