@@ -16,7 +16,7 @@ class FnHttpStatusError(AJsonPlPgSqlFunction):
     def body(self) -> str:
         return (
             f" {Arg.result} := {BFn.jsonb_build_object}("
-            f"    '{CA.HttpStatus}', ({Arg.input}->>'{CA.HttpStatus}')::SMALLINT, "
+            f"     '{CA.HttpStatus}', ({Arg.input}->>'{CA.HttpStatus}')::SMALLINT, "
             f"    '{CA.___Error___}', ({Arg.input}->>'{CA.___Error___}')::JSONB"  
-            f"  )"
+            f" );"
         )
\ No newline at end of file
