@@ -1,5 +1,5 @@
 from volsite_postgres_common.fn.json import json_fn_db
-from volsite_postgres_common.test.db.ATestDb import ATestDb
+from volsite_postgres_common.test.db.TestDb import TestDb
 from volworld_common.test.Timer import Timer
 from api.A import A
 from volsite_postgres_common.test.db.db_response_util import response_to_dict
@@ -23,7 +23,7 @@ def db_fn_open_api_validation(fn: str, req, res, attList):
 
 def json_fn_db_with_validation(
         fn: str, req: dict,
-        test_db: ATestDb, attList,
+        test_db: TestDb, attList,
         do_commit: bool = False,
         print_long_att: bool = True):
     with Timer(f"Call DB Function [{fn}]"):
